==> rapid_widgets_library-0.2.38.tar.gz: lib/paymentGateway.dart <==
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:razorpay_flutter/razorpay_flutter.dart';

class PymentGateway extends StatefulWidget {
   final PaymentGatewayParams paymentGatewayParams;
   PymentGateway({this.paymentGatewayParams});

  @override
  _PymentGatewayState createState() => _PymentGatewayState();
}

class _PymentGatewayState extends State<PymentGateway> {
   Razorpay _razorpay;
   @override
  void initState() {
    // TODO: implement initState
     _razorpay =Razorpay();
     _razorpay.on(Razorpay.EVENT_PAYMENT_SUCCESS,handlePaymentSuccess);
     _razorpay.on(Razorpay.EVENT_PAYMENT_ERROR,handlePaymentError);
     _razorpay.on(Razorpay.EVENT_EXTERNAL_WALLET, handleExternalWallet);
     super.initState();
  }
  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _razorpay.clear();
  }
   void handlePaymentSuccess(PaymentSuccessResponse response){
     Fluttertoast.showToast(msg: "SUCCESS"+response.paymentId!=null?response.paymentId:'0',
         toastLength: Toast.LENGTH_LONG);
     return (widget.paymentGatewayParams.onSuccess != null) ? widget.paymentGatewayParams.onSuccess() : null;

   }
   void handlePaymentError(PaymentFailureResponse response){
     Fluttertoast.showToast(
         msg: "ERROR: " + response.code.toString() + " - " + response.message.toString(),
         toastLength: Toast.LENGTH_LONG);
     return (widget.paymentGatewayParams.onFailure != null) ? widget.paymentGatewayParams.onFailure() : null;

   }
   void handleExternalWallet(ExternalWalletResponse response){
     Fluttertoast.showToast(msg: "Wallet:"+response.walletName.toString(),toastLength: Toast.LENGTH_LONG);
   }

   void openCheckout()async{
     var options ={
       'key': widget.paymentGatewayParams.key!='null'?widget.paymentGatewayParams.key:'rzp_test_aClrm9BsmfBxt6',
       'amount': widget.paymentGatewayParams.amount!=null?widget.paymentGatewayParams.amount:'1000',
       'name': widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Low Code Platform',
       'description':widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Payment-test',
       'prefill':{'contact':widget.paymentGatewayParams.contactNumber!='null'?widget.paymentGatewayParams.contactNumber:'1234567890',
         'email':widget.paymentGatewayParams.contactEmail!='null'?widget.paymentGatewayParams.contactEmail:'user@pwc.com'},
       'external':{
         'wallets':['paytm']
       }
     };
     try{
       _razorpay.open(options);
     }
     catch(e){
       print(e.toString());
     }
   }
  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: widget.paymentGatewayParams.textAlign,
      child:  Padding(
        padding:  EdgeInsets.only(
          left: widget.paymentGatewayParams.paddingLeft!=null?widget.paymentGatewayParams.paddingLeft:0.0,
          right:  widget.paymentGatewayParams.paddingRight!=null?widget.paymentGatewayParams.paddingRight:0.0,
          top:  widget.paymentGatewayParams.paddingTop!=null?widget.paymentGatewayParams.paddingTop:0.0,
          bottom:  widget.paymentGatewayParams.paddingBottom!=null?widget.paymentGatewayParams.paddingBottom:0.0,
        ),
        child: widget.paymentGatewayParams.iconData!=null?ElevatedButton.icon(
          onPressed: () {
            openCheckout();
          },
          label: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          icon: Icon(widget.paymentGatewayParams.iconData,size: widget.paymentGatewayParams.iconSize??0,color: widget.paymentGatewayParams.iconColor??Colors.white,),
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ):ElevatedButton(
          child: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: TextStyle(fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          onPressed: () {
            openCheckout();
          },
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ),
      ),
    );
  }
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/paymentGateway.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:razorpay_flutter/razorpay_flutter.dart';

class PymentGateway extends StatefulWidget {
   final PaymentGatewayParams paymentGatewayParams;
   PymentGateway({this.paymentGatewayParams});

  @override
  _PymentGatewayState createState() => _PymentGatewayState();
}

class _PymentGatewayState extends State<PymentGateway> {
   Razorpay _razorpay;
   @override
  void initState() {
    // TODO: implement initState
     _razorpay =Razorpay();
     _razorpay.on(Razorpay.EVENT_PAYMENT_SUCCESS,handlePaymentSuccess);
     _razorpay.on(Razorpay.EVENT_PAYMENT_ERROR,handlePaymentError);
     _razorpay.on(Razorpay.EVENT_EXTERNAL_WALLET, handleExternalWallet);
     super.initState();
  }
  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _razorpay.clear();
  }
   void handlePaymentSuccess(PaymentSuccessResponse response){
     Fluttertoast.showToast(msg: "SUCCESS"+response.paymentId!=null?response.paymentId:'0',
         toastLength: Toast.LENGTH_LONG);
     return (widget.paymentGatewayParams.onSuccess != null) ? widget.paymentGatewayParams.onSuccess() : null;

   }
   void handlePaymentError(PaymentFailureResponse response){
     Fluttertoast.showToast(
         msg: "ERROR: " + response.code.toString() + " - " + response.message.toString(),
         toastLength: Toast.LENGTH_LONG);
     return (widget.paymentGatewayParams.onFailure != null) ? widget.paymentGatewayParams.onFailure() : null;

   }
   void handleExternalWallet(ExternalWalletResponse response){
     Fluttertoast.showToast(msg: "Wallet:"+response.walletName.toString(),toastLength: Toast.LENGTH_LONG);
   }

   void openCheckout()async{
     var options ={
       'key': widget.paymentGatewayParams.key!='null'?widget.paymentGatewayParams.key:'rzp_test_aClrm9BsmfBxt6',
       'amount': widget.paymentGatewayParams.amount!=null?widget.paymentGatewayParams.amount:'1000',
       'name': widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Low Code Platform',
       'description':widget.paymentGatewayParams.platformName!='null'?widget.paymentGatewayParams.platformName:'Payment-test',
       'prefill':{'contact':widget.paymentGatewayParams.contactNumber!='null'?widget.paymentGatewayParams.contactNumber:'1234567890',
         'email':widget.paymentGatewayParams.contactEmail!='null'?widget.paymentGatewayParams.contactEmail:'user@pwc.com'},
       'external':{
         'wallets':['paytm']
       }
     };
     try{
       _razorpay.open(options);
     }
     catch(e){
       print(e.toString());
     }
   }
  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: widget.paymentGatewayParams.textAlign,
      child:  Padding(
        padding:  EdgeInsets.only(
          left: widget.paymentGatewayParams.paddingLeft!=null?widget.paymentGatewayParams.paddingLeft:0.0,
          right:  widget.paymentGatewayParams.paddingRight!=null?widget.paymentGatewayParams.paddingRight:0.0,
          top:  widget.paymentGatewayParams.paddingTop!=null?widget.paymentGatewayParams.paddingTop:0.0,
          bottom:  widget.paymentGatewayParams.paddingBottom!=null?widget.paymentGatewayParams.paddingBottom:0.0,
        ),
        child: widget.paymentGatewayParams.iconData!=null?ElevatedButton.icon(
          onPressed: () {
            openCheckout();
          },
          label: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: GoogleFonts.getFont('Roboto',fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          icon: Icon(widget.paymentGatewayParams.iconData,size: widget.paymentGatewayParams.iconSize??0,color: widget.paymentGatewayParams.iconColor??Colors.white,),
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ):ElevatedButton(
          child: Text(widget.paymentGatewayParams.paymentText!='null'?widget.paymentGatewayParams.paymentText:'Online Payment',
            style: GoogleFonts.getFont('Roboto',fontSize: widget.paymentGatewayParams.fontSize??0,color: widget.paymentGatewayParams.paymentTextColor??Colors.white),),
          onPressed: () {
            openCheckout();
          },
          style: ElevatedButton.styleFrom(
            primary: widget.paymentGatewayParams.bttnColor??Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(widget.paymentGatewayParams.borderRadius??0), // <-- Radius
            ),
          ),
        ),
      ),
    );
  }
}
